package edu.travel.commodity.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import edu.travel.commodity.entity.ShopSpec;
import edu.travel.commodity.mapper.ShopSpecMapper;
import edu.travel.commodity.service.ShopSpecService;
import edu.travel.commodity.utils.PageUtil;
import edu.travel.remote.dto.SpecDto;
import edu.travel.remote.vo.SpecVo;
import edu.travel.rpc.RPCBaseResponse;
import edu.travel.service.SysServiceImpl;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class ShopSpecServiceImpl extends SysServiceImpl<ShopSpecMapper, ShopSpec> implements ShopSpecService {


    @Override
    public Page<SpecVo> getShopSpec(Long countryId, Integer currentPage, Integer pageSize) {
        LambdaQueryWrapper<ShopSpec> query = Wrappers.<ShopSpec>lambdaQuery()
                .eq(ShopSpec::getCountryId, countryId).orderByDesc(ShopSpec::getCreateTime);
        Page<ShopSpec> page = this.page(new Page<>(currentPage, pageSize), query);
        return PageUtil.toPageEntity(page, SpecVo.class);
    }

    @Override
    public void insertOrUpdate(SpecDto specDto) {
        ShopSpec spec = getById(specDto.getSpecId());
        if (ObjectUtil.isEmpty(spec)) {
            LambdaQueryWrapper<ShopSpec> query =
                    Wrappers.<ShopSpec>lambdaQuery().eq(ShopSpec::getSpecName, specDto.getSpecName())
                            .eq(ShopSpec::getCountryId, specDto.getCountryId());
            ShopSpec one = getOne(query);
            if (one != null) {
                throw new RuntimeException("规格名称已存在");
            }
            ShopSpec bean = BeanUtil.toBean(specDto, ShopSpec.class);
            save(bean);
            return;
        }
        spec.setSpecName(specDto.getSpecName());
        updateById(spec);
    }

    /**
     * 获取规格名称（模糊查询）
     * @param specName
     * @return
     */
    @Override
    public RPCBaseResponse<List<SpecVo>> getSpecName(String specName) {
        // 模糊查询规格
        LambdaQueryWrapper<ShopSpec> query = Wrappers.<ShopSpec>lambdaQuery()
                .like(ShopSpec::getSpecName, specName);
        List<ShopSpec> specs = list(query);
        return RPCBaseResponse.success(BeanUtil.copyToList(specs, SpecVo.class));
    }
}
